<?php
/**
 * Registering meta boxes
 *
 * Using Meta Box plugin: http://www.deluxeblogtips.com/meta-box/
 *
 * @see https://docs.metabox.io/
 *
 * @param array $meta_boxes Default meta boxes. By default, there are no meta boxes.
 *
 * @return array All registered meta boxes
 */
function pallas_register_meta_boxes( $meta_boxes ) {

	$prefix = '_cmb_';

	$meta_boxes[] = array(
        'id'         => 'page_setting',
        'title'      => 'Page Setting',
        'pages'      => array('page'), 
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, 
        'fields' => array(
            array(
                'name' => 'Page Title',
                'desc' => 'Set Page Title',
                'id'   => $prefix . 'page_title',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Page SubTitle',
                'desc' => 'Set Page SubTitle',
                'id'   => $prefix . 'page_stitle',
                'type'    => 'text',
            ),
            array(
                'name' => 'Upload Background Image Top',
                'desc' => 'Recommend: 1920x1280',
                'id' => $prefix . 'bg_head',
                'type'             => 'image_advanced',
                'max_file_uploads' => 1,
            ),         
        )
    );	
	
	$meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), 
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, 
        'fields' => array(
            array(
                'name'              => 'Upload Background Image for Top Single Blog Page',
                'desc'              => 'Upload an image or enter an URL, Recommended Size: 1900 x 1024.',
                'id'                => $prefix . 'image_thumbnail',
                'type'              => 'image_advanced',
                'max_file_uploads'  => 1,
                'class'             => 'gallery link image quote video audio standard',
            ), 
            array(
                'name'  => __( 'Content Right', 'cmb' ),
                'desc'  => __( 'Content Right Title', 'cmb' ),
                'id'    => $prefix . 'right_text',
                'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
                'class' => 'gallery link image quote video audio standard',
            ),
            array(
                'name'  => __( 'Excerpt Post', 'cmb' ),
                'desc'  => __( 'Text show on blog page', 'cmb' ),
                'id'    => $prefix . 'ex_post',
                'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
                'class' => 'gallery link image quote video audio standard',
            ),
                     
        )
    );

    $meta_boxes[] = array(
        'id'         => 'portfolio_setting',
        'title'      => 'Portfolio Setting',
        'pages'      => array('portfolio', 'slide'), 
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, 
        'fields' => array(
            array(
                'name' => 'Upload Background Image Top',
                'desc' => '',
                'id' => $prefix . 'bg_folio',
                'type'             => 'image_advanced',
                'max_file_uploads' => 1,
            ),
            array(
                'name' => 'Top Title',
                'desc' => '',
                'id'   => $prefix . 'folio_title',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Top SubTitle',
                'desc' => '',
                'id'   => $prefix . 'folio_stitle',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Video Link Popup',
                'desc' => 'Only use for Portfolio Lightbox Video. <br>Ex: http://player.vimeo.com/video/88883554 or http://www.youtube.com/embed/eP2VWNtU5rw',
                'id'   => $prefix . 'folio_video',
                'type'    => 'text',
            ),    
        )
    );

	return $meta_boxes;
}

add_filter( 'rwmb_meta_boxes', 'pallas_register_meta_boxes' );
